@@ -1,4 +1,4 @@
-// Copyright (C) 2012-2017 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2012-2024 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -11,7 +11,7 @@
 #include <dhcp/opaque_data_tuple.h>
 #include <dhcp/option.h>
 #include <exceptions/exceptions.h>
-#include <util/io_utilities.h>
+#include <util/io.h>
 
 #include <stdint.h>
 #include <utility>
@@ -33,7 +33,6 @@ public:
         isc::Exception(file, line, what) { };
 };
 
-
 /// @brief Data types of DHCP option fields.
 ///
 /// @warning The order of data types matters: OPT_UNKNOWN_TYPE
@@ -60,6 +59,8 @@ enum OptionDataType {
     OPT_STRING_TYPE,
     OPT_TUPLE_TYPE,
     OPT_FQDN_TYPE,
+    // Type to be used only internally. Allows convenient notation of the option config.
+    OPT_INTERNAL_TYPE,
     OPT_RECORD_TYPE,
     OPT_UNKNOWN_TYPE
 };
@@ -68,6 +69,7 @@ enum OptionDataType {
 struct OptionDefParams {
     const char*             name;           // option name
     uint16_t                code;           // option code
+    const char*             space;          // option space
     OptionDataType          type;           // data type
     bool                    array;          // is array
     const OptionDataType*   records;        // record fields
@@ -400,7 +402,6 @@ public:
     /// @param tuple reference of the tuple to read into
     /// @throw isc::dhcp::BadDataTypeCast when the data being read
     /// is truncated.
-    /// @return tuple being read.
     static void readTuple(const std::vector<uint8_t>& buf,
                           OpaqueDataTuple& tuple);
 
@@ -420,6 +421,16 @@ public:
     static void writeTuple(const OpaqueDataTuple& tuple,
                            std::vector<uint8_t>& buf);
 
+    /// @brief Returns Length Field Type for a tuple.
+    ///
+    /// Returns Length Field Type for a tuple basing on the given
+    /// Option v4/v6 Universe.
+    ///
+    /// @param u specifies universe (V4 or V6)
+    /// @return By default 1 octet Length Field Type for V4 option
+    /// or 2 octets Length Field Type for V6 option
+    static OpaqueDataTuple::LengthFieldType getTupleLenFieldType(Option::Universe u);
+
     /// @brief Read boolean value from a buffer.
     ///
     /// @param buf input buffer.
@@ -610,9 +621,11 @@ public:
 
     /// @brief Read string value from a buffer.
     ///
+    /// To be compliant with RFC 2132, Sec. 2, trailing NULLs are trimmed.
     /// @param buf input buffer.
     ///
     /// @return string value being read.
+    /// @throw isc::dhcp::OutOfRange is the payload contains only NULLs.
     static std::string readString(const std::vector<uint8_t>& buf);
 
     /// @brief Write UTF8-encoded string into a buffer.
