@@ -1,6 +1,6 @@
 #!/bin/sh
 
-# Copyright (C) 2019-2023 Internet Systems Consortium, Inc. ("ISC")
+# Copyright (C) 2019-2024 Internet Systems Consortium, Inc. ("ISC")
 #
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -12,9 +12,6 @@
 # including leases, reservations, etc... Use at your own peril.
 # Reference tables will be left in-tact.
 
-# shellcheck disable=SC1091
-# SC1091: Not following: ... was not specified as input (see shellcheck -x).
-
 # Exit with error if commands exit with non-zero and if undefined variables are
 # used.
 set -eu
@@ -23,12 +20,16 @@ set -eu
 # SC2034: ... appears unused. Verify use (or export if used externally).
 prefix="/usr"
 
-# Include utilities. Use installed version if available and
-# use build version if it isn't.
-if test -f "${prefix}/share/kea/scripts/admin-utils.sh"; then
-    . "${prefix}/share/kea/scripts/admin-utils.sh"
+# Include utilities based on location of this script. Check for sources first,
+# so that the unexpected situations with weird paths fall on the default
+# case of installed.
+script_path=$(cd "$(dirname "${0}")" && pwd)
+if test "${script_path}" = "/build/kea/src/kea-2.6.0/src/share/database/scripts/mysql"; then
+    # shellcheck source=./src/bin/admin/admin-utils.sh.in
+    . "/build/kea/src/kea-2.6.0/src/bin/admin/admin-utils.sh"
 else
-    . "/build/kea/src/kea-2.4.1/src/bin/admin/admin-utils.sh"
+    # shellcheck source=./src/bin/admin/admin-utils.sh.in
+    . "${prefix}/share/kea/scripts/admin-utils.sh"
 fi
 
 # First argument must be the expected schema version <major>.<minor>
